# Project
DjangoNest: A Python CMS with the Elegance of Django
DjangoNest is a Content Management System (CMS) built with a powerful combination of Python and Django, providing an agile and flexible development experience. The project was born from the need to create an intuitive solution for efficient content management in web environments.
# Functionalities
 [![Typing SVG](https://readme-typing-svg.demolab.com?font=Fira+Code&size=25&pause=1000&color=B200F7&multiline=true&random=&width=435&height=200&lines=+Intuitive+content+management;+Robust+API+for+integration;+Extensible+through+plugins;User-friendly+administrative+interface)](https://git.io/typing-svg)
![logo](https://i.ibb.co/xsFqYxs/logo.png)

# User Guide
```pip3 install django-nest```

```poetry shell```

```poetry run startproject "my_project" ```

```cd my_project```

```poetry install```

```poetry run runserver```

## Contributors 🧑🏾‍💻

| Github User                                            | Face 🤭                                                                                          |
| ------------------------------------------------------ | ------------------------------------------------------------------------------------------------ |
| [@pratadaniel94](https://www.github.com/pratadaniel94) | <img src="https://avatars.githubusercontent.com/u/27214522?v=4" height="30px" align="center"  /> |


Contributions are welcome! Feel free to open issues and submit pull requests.